/*
 *  Copyright (c) 2023 Fraunhofer Institute for Applied Information Technology
 *
 *  This program and the accompanying materials are made available under the
 *  terms of the Apache License, Version 2.0 which is available at
 *  https://www.apache.org/licenses/LICENSE-2.0
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 */

package org.fraunhofer.fit.extension.extractor.model;

import java.lang.reflect.Field;
import java.util.HashMap;
import java.util.Map;

public class ValidatorModel {

    private String name;
    private String pid;
    private String licence;
    private String publisher;
    private String title;
    private String publicationDate;
    private String modifiedDate;
    private String description;
    private String[] keywords;
    private String dataLink;
    private String dataAccessLevel;
    private String mimeType;
    private String language;
    private String contactPoint;
    private int byteSize;
    private String version;
    private String validationScoreDesc;
    private float validationScore;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getPid() {
        return pid;
    }

    public void setPid(String pid) {
        this.pid = pid;
    }

    public String getLicence() {
        return licence;
    }

    public void setLicence(String licence) {
        this.licence = licence;
    }

    public String getPublisher() {
        return publisher;
    }

    public void setPublisher(String publisher) {
        this.publisher = publisher;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getPublicationDate() {
        return publicationDate;
    }

    public void setPublicationDate(String publicationDate) {
        this.publicationDate = publicationDate;
    }

    public String getModifiedDate() {
        return modifiedDate;
    }

    public void setModifiedDate(String modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String[] getKeywords() {
        return keywords;
    }

    public void setKeywords(String[] keywords) {
        this.keywords = keywords;
    }

    public String getDataLink() {
        return dataLink;
    }

    public void setDataLink(String dataLink) {
        this.dataLink = dataLink;
    }

    public String getDataAccessLevel() {
        return dataAccessLevel;
    }

    public void setDataAccessLevel(String dataAccessLevel) {
        this.dataAccessLevel = dataAccessLevel;
    }

    public String getMimeType() {
        return mimeType;
    }

    public void setMimeType(String mimeType) {
        this.mimeType = mimeType;
    }

    public String getLanguage() {
        return language;
    }

    public void setLanguage(String language) {
        this.language = language;
    }

    public String getContactPoint() {
        return contactPoint;
    }

    public void setContactPoint(String contactPoint) {
        this.contactPoint = contactPoint;
    }

    public int getByteSize() {
        return byteSize;
    }

    public void setByteSize(int byteSize) {
        this.byteSize = byteSize;
    }

    public String getVersion() {
        return version;
    }

    public void setVersion(String version) {
        this.version = version;
    }

    public void setValidationScore(float validationScore) {
        this.validationScore = validationScore;
    }

    public void setValidationScoreDesc(String validationScoreDesc) {
        this.validationScoreDesc = validationScoreDesc;
    }

    public void print() {

        System.out.println("======= printing all FAIR validator ============");
        Field[] fields = ValidatorModel.class.getDeclaredFields();

        for (Field field : fields) {
            field.setAccessible(true);
            String name = field.getName();
            try {
                Object value = field.get(this);
                System.out.println(name + " :" + value);
            } catch (IllegalAccessException e) {
                e.printStackTrace();
            }
        }
    }

    public Map<String, Object> getProperties() {

        Map<String, Object> properties = new HashMap<>();
        Field[] fields = ValidatorModel.class.getDeclaredFields();

        for (Field field : fields) {
            field.setAccessible(true);
            String name = field.getName();
            try {
                Object value = field.get(this);
                properties.put(name, value);
            } catch (IllegalAccessException e) {
                e.printStackTrace();
            }
        }
        return properties;
    }
}
